@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.18_03';
+  our $VERSION = '0.18_04';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -103,25 +103,52 @@ package Art::World {
     }
   }
 
+  # TODO If an Agent work is  collected, it's reputation should go up
   role Fame {
-    # TODO If an Agent work is  collected, it's reputation should go up
-    method bump_fame( Num $gain = $self->config->{ FAME }->{ DEFAULT_BUMP } ) {
+    # Private
+    method $update_fame( Num $difference ) {
       # Dynamic attribute accessor
       my $attribute = $self->isa( 'Art::World::Work' ) ?
-          'aura' : 'reputation';
+        'aura' : 'reputation';
       if ( $self->can( $attribute )) {
-        if ( $self->$attribute + $gain >= 0 ) {
-          $self->$attribute( $self->$attribute + $gain )
+        if ( $self->$attribute + $difference >= 0 ) {
+          $self->$attribute( $self->$attribute + $difference )
         } else {
           carp 'You tried to update ' . $attribute . ' to a value smaller ' .
-              'than zero. Nothing changed.';
+            'than zero. Nothing changed.';
         }
         return $self->$attribute;
       } else {
         carp 'No such attribute ' . $attribute .
-            ' or we don\'t manage this kind of entity ' . Meta->get_class( $self );
+          ' or we don\'t manage this kind of entity ' . Meta->get_class( $self );
       }
     }
+
+    multi method bump_fame( PositiveNum $gain ) {
+      say "PositiveNum";
+      $self->$update_fame( $gain );
+    }
+
+    multi method bump_fame( NegativeNum $loss ) {
+      say "NegativeNum";
+      $self->$update_fame( $loss )
+    }
+
+    multi method bump_fame {
+      say "No num";
+      $self->$update_fame( $self->config->{ FAME }->{ DEFAULT_BUMP });
+    }
+  }
+
+  role Invitation {
+    multi method invite ( ArrayRef[ Agent ] *people  ) {
+
+    }
+
+    multi method invite ( ArrayRef[ Agent ] *people,  Event *event  ) {
+
+    }
+
   }
 
   role Language {
@@ -193,13 +220,9 @@ package Art::World {
         has reader;
       }
 
-      class Place with Space, Fame {
-        class Institution {
+      class Place with Space, Fame, Invitation {
 
-          class School {
-            has student;
-            has teachers;
-          }
+        class Institution {
 
           class Gallery with Exhibit, Buyer {
 
@@ -217,13 +240,20 @@ package Art::World {
 
           class Museum with Exhibit;
 
+          class School {
+            has student;
+            has teachers;
+          }
+
         }
 
         class Squat with Underground;
         class Workshop;
+
       }
 
       class Website;
+
     }
 
     class Agent with Active, Fame {
@@ -261,7 +291,7 @@ package Art::World {
       class Artist {
 
         has artworks   ( type => ArrayRef );
-        has collectors ( type => ArrayRef[Collector], default => sub { [] } );
+        has collectors ( type => ArrayRef[ Collector ], default => sub { [] } );
         has collected  ( type => Bool, default => false, is => rw );
         has status (
           enum => [ 'underground', 'homogenic' ],
@@ -294,7 +324,7 @@ package Art::World {
       class Collector with Active, Buyer {
         has money! ( type => Num, is => rw );
         has collection (
-          type    => ArrayRef[Artwork, 0 ],
+          type    => ArrayRef[ Artwork, 0 ],
           default => sub { [] },
           is      => rw, );
       }
@@ -381,6 +411,8 @@ package Art::World {
         return join ' ', $buzz->@*;
       }
 
+      method random_set_of_agents ( Int $num ) { }
+
       method titlify( Str $token ) {
         return join '', map { ucfirst lc $_ } split /(\s+)/, $token;
       }
@@ -451,9 +483,25 @@ Role for L<C<Places>|Art::World/"Place"> that display some  L<C<Artworks>|Art::W
 C<Fame> role provide ways to control the aura and reputation that various
 C<Agents>, C<Places> or C<Works> have. Cannot be negative.
 
-It has an handy C<bump_fame()> method that self-bump the fame count. It can be
-passed a positive C<Num>, a negative C<Num> (so that the fame will get lower)
-and even no parameter, in that case it will just add 1.
+It has an handy C<bump_fame()> method that I<self-bump> the fame count. It can
+be used in three specific maneers:
+
+=over 2
+
+=item pass a C<PositiveNum>
+
+The fame will go higher
+
+=item pass a C<NegativeNum>
+
+The fame he fame will go lower
+
+=item no parameter
+
+In that case the value defined by C<$self->config->{ FAME }->{ DEFAULT_BUMP }>
+will be used to increase the reputation.
+
+=back
 
   my $artist = Art::World->new_artist(
     reputation => 0.42,
@@ -622,6 +670,11 @@ Yet another kind of C<Place>, an institution with a lot of L<C<Artworks>|Art::Wo
 
 =head2 Place
 
+A `Place` must `invite()` all kind of `Agents` that produce `Work` or other kind
+of valuable social interactions. Depending of the total `reputation` of the
+`Place` it will determine it's `underground` status: when going out of the
+`underground`, it will become an institution.
+
 =head2 Playground
 
 A generic space where C<Art::World> C<Agents> can do all kind of weird things.
@@ -634,6 +687,9 @@ A generic space where C<Art::World> C<Agents> can do all kind of weird things.
 
 =head2 Squat
 
+A place were art world agents are doing things. A squat that is not underground
+anymore become an institution.
+
 =head2 Theory
 
 When some abstract concept turns to some said or written stuff.
